@@ -16,7 +16,7 @@ class EventRoutingBackendsConfig(AppConfig):
         """
         Import the signals and transformers for initialization.
         """
-        super(EventRoutingBackendsConfig, self).ready()
+        super().ready()
         # pylint: disable=import-outside-toplevel, unused-import
         from event_routing_backends.processors.caliper import event_transformers as caliper_event_transformers
         from event_routing_backends.processors.xapi import event_transformers as xapi_event_transformers
