@@ -3,8 +3,8 @@ Test the CaliperEnvelopProcessor.
 """
 from datetime import datetime
 from unittest import TestCase
+from unittest.mock import patch, sentinel
 
-from mock import patch, sentinel
 from pytz import UTC
 
 from event_routing_backends.helpers import convert_datetime_to_iso
@@ -34,6 +34,6 @@ class TestCaliperEnvelopProcessor(TestCase):
         self.assertEqual(result, {
             'sensor': self.sensor_id,
             'sendTime': convert_datetime_to_iso(str(FROZEN_TIME)),
-            'data': self.sample_event,
+            'data': [self.sample_event],
             'dataVersion': CALIPER_EVENT_CONTEXT
         })
